@@ -1,8 +1,6 @@
 import os
 
-from dynaconf import Dynaconf
-
-# Copyright 2020 Tim Schwenke. Licensed under the Apache License 2.0
+from dynaconf import Dynaconf  # type: ignore
 
 
 current_directory = os.path.dirname(os.path.realpath(__file__))
