@@ -1,19 +1,17 @@
-from typing import Dict, Type
+"""
+Helpful wrappers around Prometheus client library. Should be used exclusively
+in this package to ensure consistent namespace / subsystem.
+"""
+
+from typing import Dict
 
 from prometheus_client import Counter, Gauge, Histogram
 
 from prometheus_ecs_discoverer import s
 
-# Copyright 2020 Tim Schwenke. Licensed under the Apache License 2.0
 
-"""
-Helpful wrappers around Prometheus client library. Should be used exclusively 
-in this package to ensure consistent namespace / subsystem.
-"""
-
-
-def gauge(name: str, documentation: str, labels: tuple = ()) -> Type[Gauge]:
-    """Builds a gauge with configured namespace / subsystem."""
+def gauge(name: str, documentation: str, labels: tuple = ()) -> Gauge:
+    """Build a gauge with configured namespace / subsystem."""
 
     return Gauge(
         name,
@@ -24,8 +22,8 @@ def gauge(name: str, documentation: str, labels: tuple = ()) -> Type[Gauge]:
     )
 
 
-def counter(name: str, documentation: str, labels: tuple = ()) -> Type[Counter]:
-    """Builds a counter with configured namespace / subsystem."""
+def counter(name: str, documentation: str, labels: tuple = ()) -> Counter:
+    """Build a counter with configured namespace / subsystem."""
 
     return Counter(
         name,
@@ -41,8 +39,8 @@ def histogram(
     documentation: str,
     labels: tuple = (),
     buckets: tuple = Histogram.DEFAULT_BUCKETS,
-) -> Type[Histogram]:
-    """Builds a histogram with configured namespace / subsystem."""
+) -> Histogram:
+    """Build a histogram with configured namespace / subsystem."""
 
     return Histogram(
         name,
@@ -55,7 +53,7 @@ def histogram(
 
 
 def info(labels: Dict[str, str], name: str = "info") -> None:
-    """Creates a gauge with the given label value pairs.
+    """Create a gauge with the given label value pairs.
 
     Helps with exposing static info gauges.
     """
